@@ -1,22 +1,23 @@
 #!/bin/sh
 #
-# Copyright © 2012-2015 Inria.  All rights reserved.
+# Copyright © 2012-2018 Inria.  All rights reserved.
 # See COPYING in top-level directory.
 #
 
+echo "############################"
+echo "Running on:"
+uname -a
+echo "Tarball: $1"
+echo "############################"
+
 set -e
 set -x
 
 # environment variables
 test -f $HOME/.ciprofile && . $HOME/.ciprofile
 
-# remove everything but the last 10 builds
-ls | grep -v ^hwloc- | grep -v ^job- | xargs rm -rf || true
-ls -td hwloc-* | tail -n +11 | xargs chmod u+w -R || true
-ls -td hwloc-* | tail -n +11 | xargs rm -rf || true
-
-# find the tarball, extract it
-tarball=$(ls -tr hwloc-*.tar.gz | grep -v build.tar.gz | tail -1)
+# extract the tarball
+tarball="$1"
 basename=$(basename $tarball .tar.gz)
 test -d $basename && chmod -R u+rwX $basename && rm -rf $basename
 tar xfz $tarball
@@ -35,8 +36,4 @@ make check
 tests/hwloc/wrapper.sh utils/lstopo/lstopo-no-graphics
 cd ..
 
-# cleanup
-rm -rf doc build-plugins-debug/doc
-cd ..
-tar cfz ${basename}.build.tar.gz $basename
-rm -rf $basename
+exit 0
