@@ -75,8 +75,6 @@ int MPI_Abort(MPI_Comm comm, int errorcode)
 {
     int mpi_errno = MPI_SUCCESS;
     MPIR_Comm *comm_ptr = NULL;
-    /* FIXME: 100 is arbitrary and may not be long enough */
-    char abort_str[100] = "", comm_name[MPI_MAX_OBJECT_NAME];
     int len = MPI_MAX_OBJECT_NAME;
     MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPI_ABORT);
 
@@ -125,15 +123,17 @@ int MPI_Abort(MPI_Comm comm, int errorcode)
         comm_ptr = MPIR_Process.comm_self;
     }
 
-
+    char abort_str[MPI_MAX_OBJECT_NAME + 100] = "";
+    char comm_name[MPI_MAX_OBJECT_NAME];
     MPIR_Comm_get_name_impl(comm_ptr, comm_name, &len);
     if (len == 0) {
         MPL_snprintf(comm_name, MPI_MAX_OBJECT_NAME, "comm=0x%X", comm);
     }
     if (!MPIR_CVAR_SUPPRESS_ABORT_MESSAGE)
         /* FIXME: This is not internationalized */
-        MPL_snprintf(abort_str, 100, "application called MPI_Abort(%s, %d) - process %d", comm_name,
-                     errorcode, comm_ptr->rank);
+        MPL_snprintf(abort_str, sizeof(abort_str),
+                     "application called MPI_Abort(%s, %d) - process %d", comm_name, errorcode,
+                     comm_ptr->rank);
     mpi_errno = MPID_Abort(comm_ptr, mpi_errno, errorcode, abort_str);
     /* --BEGIN ERROR HANDLING-- */
     if (mpi_errno != MPI_SUCCESS)
