@@ -98,8 +98,8 @@ MPIR_Process_t MPIR_Process = { OPA_INT_T_INITIALIZER(MPICH_MPI_STATE__PRE_INIT)
      /* all other fields in MPIR_Process are irrelevant */
 MPIR_Thread_info_t MPIR_ThreadInfo = { 0 };
 
-#if defined(MPICH_IS_THREADED) && defined(MPL_TLS_SPECIFIER)
-MPL_TLS_SPECIFIER MPIR_Per_thread_t MPIR_Per_thread = { 0 };
+#if defined(MPICH_IS_THREADED) && defined(MPL_TLS)
+MPL_TLS MPIR_Per_thread_t MPIR_Per_thread = { 0 };
 #else
 MPIR_Per_thread_t MPIR_Per_thread = { 0 };
 #endif
@@ -252,6 +252,20 @@ static int thread_cs_init(void)
 
     MPID_THREADPRIV_KEY_CREATE;
 
+    {
+        /*
+         * Hack to workaround an Intel compiler bug on macOS. Touching
+         * MPIR_Per_thread in this file forces the compiler to allocate it as TLS.
+         * See https://github.com/pmodels/mpich/issues/3437.
+         */
+        MPIR_Per_thread_t *per_thread = NULL;
+
+        MPID_THREADPRIV_KEY_GET_ADDR(MPIR_ThreadInfo.isThreaded, MPIR_Per_thread_key,
+                                     MPIR_Per_thread, per_thread, &err);
+        MPIR_Assert(err == 0);
+        memset(per_thread, 0, sizeof(MPIR_Per_thread_t));
+    }
+
     MPL_DBG_MSG(MPIR_DBG_INIT, TYPICAL, "Created global mutex and private storage");
     return MPI_SUCCESS;
 }
@@ -560,15 +574,17 @@ int MPIR_Init_thread(int *argc, char ***argv, int required, int *provided)
     /* Set the number of tag bits. The device may override this value. */
     MPIR_Process.tag_bits = MPIR_TAG_BITS_DEFAULT;
 
-    mpi_errno = MPID_Init(argc, argv, required, &thread_provided, &has_args, &has_env);
-    if (mpi_errno)
-        MPIR_ERR_POP(mpi_errno);
-
     /* Create complete request to return in the event of immediately complete
      * operations. Use a SEND request to cover all possible use-cases. */
     MPIR_Process.lw_req = MPIR_Request_create(MPIR_REQUEST_KIND__SEND);
+    MPIR_ERR_CHKANDSTMT(MPIR_Process.lw_req == NULL, mpi_errno, MPIX_ERR_NOREQ, goto fn_fail,
+                        "**nomemreq");
     MPIR_cc_set(&MPIR_Process.lw_req->cc, 0);
 
+    mpi_errno = MPID_Init(argc, argv, required, &thread_provided, &has_args, &has_env);
+    if (mpi_errno)
+        MPIR_ERR_POP(mpi_errno);
+
     /* Initialize collectives infrastructure */
     mpi_errno = MPII_Coll_init();
     if (mpi_errno)
