@@ -123,7 +123,7 @@ int MPI_Testany(int count, MPI_Request array_of_requests[], int *indx,
     int n_inactive;
     int active_flag;
     int last_disabled_anysource = -1;
-    int first_nonnull = 0;
+    int first_nonnull = count;
     int mpi_errno = MPI_SUCCESS;
     MPIR_CHKLMEM_DECL(1);
     MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPI_TESTANY);
@@ -196,7 +196,7 @@ int MPI_Testany(int count, MPI_Request array_of_requests[], int *indx,
                     request_ptrs[i] = NULL;
                 }
             } else {
-                if (!first_nonnull)
+                if (first_nonnull == count)
                     first_nonnull = i;
             }
         } else {
