@@ -38,7 +38,7 @@ static void ADIOI_Read_and_exch(ADIO_File fd, void *buf, MPI_Datatype
                                 ADIO_Offset
                                 min_st_offset, ADIO_Offset fd_size,
                                 ADIO_Offset * fd_start, ADIO_Offset * fd_end,
-                                int *buf_idx, int *error_code);
+                                MPI_Aint * buf_idx, int *error_code);
 static void ADIOI_R_Exchange_data(ADIO_File fd, void *buf, ADIOI_Flatlist_node
                                   * flat_buf, ADIO_Offset * offset_list, ADIO_Offset
                                   * len_list, int *send_size, int *recv_size,
@@ -51,7 +51,7 @@ static void ADIOI_R_Exchange_data(ADIO_File fd, void *buf, ADIOI_Flatlist_node
                                   ADIO_Offset fd_size,
                                   ADIO_Offset * fd_start, ADIO_Offset * fd_end,
                                   ADIOI_Access * others_req,
-                                  int iter, MPI_Aint buftype_extent, int *buf_idx);
+                                  int iter, MPI_Aint buftype_extent, MPI_Aint * buf_idx);
 static void ADIOI_R_Exchange_data_alltoallv(ADIO_File fd, void *buf, ADIOI_Flatlist_node
                                             * flat_buf, ADIO_Offset * offset_list, ADIO_Offset
                                             * len_list, int *send_size, int *recv_size,
@@ -64,7 +64,7 @@ static void ADIOI_R_Exchange_data_alltoallv(ADIO_File fd, void *buf, ADIOI_Flatl
                                             ADIO_Offset fd_size,
                                             ADIO_Offset * fd_start, ADIO_Offset * fd_end,
                                             ADIOI_Access * others_req,
-                                            int iter, MPI_Aint buftype_extent, int *buf_idx);
+                                            int iter, MPI_Aint buftype_extent, MPI_Aint * buf_idx);
 static void ADIOI_Fill_user_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
                                    * flat_buf, char **recv_buf, ADIO_Offset
                                    * offset_list, ADIO_Offset * len_list,
@@ -114,7 +114,7 @@ void ADIOI_GPFS_ReadStridedColl(ADIO_File fd, void *buf, int count,
     ADIO_Offset *count_sizes;
     int ii;
     ADIO_Offset *len_list = NULL;
-    int *buf_idx = NULL;
+    MPI_Aint *buf_idx = NULL;
 
     GPFSMPIO_T_CIO_RESET(r);
 
@@ -485,7 +485,7 @@ static void ADIOI_Read_and_exch(ADIO_File fd, void *buf, MPI_Datatype
                                 ADIO_Offset * len_list, int contig_access_count, ADIO_Offset
                                 min_st_offset, ADIO_Offset fd_size,
                                 ADIO_Offset * fd_start, ADIO_Offset * fd_end,
-                                int *buf_idx, int *error_code)
+                                MPI_Aint * buf_idx, int *error_code)
 {
 /* Read in sizes of no more than coll_bufsize, an info parameter.
    Send data to appropriate processes.
@@ -821,7 +821,7 @@ static void ADIOI_R_Exchange_data(ADIO_File fd, void *buf, ADIOI_Flatlist_node
                                   ADIO_Offset min_st_offset, ADIO_Offset fd_size,
                                   ADIO_Offset * fd_start, ADIO_Offset * fd_end,
                                   ADIOI_Access * others_req,
-                                  int iter, MPI_Aint buftype_extent, int *buf_idx)
+                                  int iter, MPI_Aint buftype_extent, MPI_Aint * buf_idx)
 {
     int i, j, k = 0, tmp = 0, nprocs_recv, nprocs_send;
     char **recv_buf = NULL;
@@ -1109,7 +1109,7 @@ static void ADIOI_R_Exchange_data_alltoallv(ADIO_File fd, void *buf, ADIOI_Flatl
                                             ADIO_Offset min_st_offset, ADIO_Offset fd_size,
                                             ADIO_Offset * fd_start, ADIO_Offset * fd_end,
                                             ADIOI_Access * others_req,
-                                            int iter, MPI_Aint buftype_extent, int *buf_idx)
+                                            int iter, MPI_Aint buftype_extent, MPI_Aint * buf_idx)
 {
     int i, j, k = 0, tmp = 0, nprocs_recv, nprocs_send;
     char **recv_buf = NULL;
